hal/libhal libhal.c,1.21,1.22 libhal.h,1.15,1.16

David Zeuthen david at freedesktop.org
Thu Jul 29 10:07:11 PDT 2004


Update of /cvs/hal/hal/libhal
In directory pdx:/tmp/cvs-serv11505/libhal

Modified Files:
	libhal.c libhal.h 
Log Message:
2004-07-29  David Zeuthen  <david at fubar.dk>

	* libhal/libhal.[ch]: s/namespace/property_namespace/ to not break
	using libhal from C++. Pointed out by Simone Gotti 
	<simone.gotti at email.it>

2004-07-29  David Zeuthen  <david at fubar.dk>

	Patch from Kay Sievers <kay.sievers at vrfy.org>

	* configure.in:
	* doc/spec/hal-spec.html:
	* doc/spec/hal-spec.xml.in:
	* hald/linux/block_class_device.c:
	* hald/linux/volume_id/volume_id.c: (get_buffer),
	(probe_hfs_hfsplus), (probe_ntfs), (volume_id_probe):
	* hald/linux/volume_id/volume_id.h:
	Here is support for recognition of hfs and hfsplus filesystems on
	a main block device, like a CD. Only the first partition is
	returned with the probe.



Index: libhal.h
===================================================================
RCS file: /cvs/hal/hal/libhal/libhal.h,v
retrieving revision 1.15
retrieving revision 1.16
diff -u -d -r1.15 -r1.16
--- libhal.h	22 Jul 2004 00:31:45 -0000	1.15
+++ libhal.h	29 Jul 2004 17:07:09 -0000	1.16
@@ -261,7 +261,7 @@
 dbus_bool_t hal_agent_device_matches (LibHalContext *ctx,
 				      const char *udi1,
 				      const char *udi2,
-				      const char *namespace);
+				      const char *property_namespace);
 
 char **hal_manager_find_device_string_match (LibHalContext *ctx,
 					     const char *key,




More information about the hal-commit mailing list
Index: libhal.c
===================================================================
RCS file: /cvs/hal/hal/libhal/libhal.c,v
retrieving revision 1.21
retrieving revision 1.22
diff -u -d -r1.21 -r1.22
--- libhal.c	22 Jul 2004 00:31:45 -0000	1.21
+++ libhal.c	29 Jul 2004 17:07:09 -0000	1.22
@@ -1646,7 +1646,7 @@
  *  @param  ctx                 The context for the connection to hald
  *  @param  udi1		Unique Device Id for device 1
  *  @param  udi2		Unique Device Id for device 2
  *  @param  namespace		Namespace for set of devices, e.g. "usb"
  *  @return			TRUE if all properties starting
  *				with the given namespace parameter
  *				from one device is in the other and 
@@ -1655,7 +1655,7 @@
 dbus_bool_t
 hal_agent_device_matches (LibHalContext *ctx, 
 			  const char *udi1, const char *udi2,
-			  const char *namespace)
+			  const char *property_namespace)
 {
 	DBusError error;
 	DBusMessage *message;
@@ -1677,7 +1677,7 @@
 	dbus_message_iter_init (message, &iter);
 	dbus_message_iter_append_string (&iter, udi1);
 	dbus_message_iter_append_string (&iter, udi2);
-	dbus_message_iter_append_string (&iter, namespace);
+	dbus_message_iter_append_string (&iter, property_namespace);
 
 	dbus_error_init (&error);
 	reply = dbus_connection_send_with_reply_and_block (ctx->connection,
@@ -1646,7 +1646,7 @@
  *  @param  udi1		Unique Device Id for device 1
  *  @param  udi2		Unique Device Id for device 2
- *  @param  namespace		Namespace for set of devices, e.g. "usb"
+ *  @param  property_namespace	Namespace for set of devices, e.g. "usb"
  *  @return			TRUE if all properties starting
  *				with the given namespace parameter
